# Permission Resolver

A zero-dependency RBAC + ABAC permission resolving engine for any Node.js or TypeScript application.

> Easily use it in Express, NestJS, React, or microservices.

---

## Installation

```bash
npm install @ymerncloud/permission-resolver
```

## Usage

```bash

const rules: PermissionRule[] = [
  {
    resource: "document",
    action: "read",
    allowedRoles: ["editor", "manager"],
    attributeCondition: {
      and: [
        { equals: ["subject.team", "resource.team"] },
        { greaterThanOrEqual: ["subject.level", 2] },
      ],
    },
  },
];

const resolver = new PermissionResolver(rules);

const subject = {
  id: "user-1",
  roles: ["editor"],
  attributes: { team: "alpha", level: 3 },
};

const resource = {
  type: "document",
  attributes: { team: "alpha" },
};

console.log(resolver.can(subject, resource, "read")); // ✅ true


```
