import { PermissionRule, Subject, Resource, Action } from "./types";
import { evaluateCondition } from "./utils/conditionEvaluator";

export class PermissionResolver {
  constructor(private rules: PermissionRule[] = []) {}

  public addRule(rule: PermissionRule) {
    this.rules.push(rule);
  }

  public can(subject: Subject, resource: Resource, action: Action): boolean {
    const matchingRules = this.rules.filter(
      rule => rule.resource === resource.type && rule.action === action
    );

    for (const rule of matchingRules) {
      const roleAllowed =
        !rule.allowedRoles || rule.allowedRoles.some(role => subject.roles.includes(role));

      const attributesAllowed =
        !rule.attributeCondition || evaluateCondition(rule.attributeCondition, { subject, resource });

      if (roleAllowed && attributesAllowed) {
        return true;
      }
    }

    return false;
  }
}
