import { Subject, Resource, PermissionRule } from "../types";
import { PermissionResolver } from "../PermissionResolver";

export function flattenPermissionsForSubject(
  subject: Subject,
  resources: Resource[],
  rules: PermissionRule[]
): string[] {
  const resolver = new PermissionResolver(rules);
  const permissions: string[] = [];

  for (const resource of resources) {
    const actions = Array.from(
      new Set(rules.filter(r => r.resource === resource.type).map(r => r.action))
    );

    for (const action of actions) {
      if (resolver.can(subject, resource, action)) {
        permissions.push(`${resource.type}:${action}`);
      }
    }
  }

  return permissions;
}
